class Query():
    def __init__(self):
        raise NotImplementedError()
